#ifndef DOWNLOADQUALITYDIALOG_H
#define DOWNLOADQUALITYDIALOG_H

#include "abstractdialog.h"

class QCheckBox;
class QDialogButtonBox;
class QScrollArea;
class QGridLayout;

class DownloadFormatDialog : public AbstractDialog
{
    Q_OBJECT
public:
    explicit DownloadFormatDialog(QWidget *parent = 0);

private slots:
    void saveSettings();

private:
    void loadSettings();
    void setLandscapeLayout();
    void setPortraitLayout();

private:
    QCheckBox *m_youtube1080Checkbox;
    QCheckBox *m_youtube720Checkbox;
    QCheckBox *m_youtube480Checkbox;
    QCheckBox *m_youtube360Checkbox;
    QCheckBox *m_youtubeNormalCheckbox;
    QCheckBox *m_dailymotion720Checkbox;
    QCheckBox *m_dailymotion480Checkbox;
    QCheckBox *m_dailymotionNormalCheckbox;
    QCheckBox *m_vimeo720Checkbox;
    QCheckBox *m_vimeo360Checkbox;
    QCheckBox *m_vimeoMobileCheckbox;
    QDialogButtonBox *m_buttonBox;
    QScrollArea *m_scrollArea;
    QGridLayout *m_grid;
};

#endif // DOWNLOADQUALITYDIALOG_H
